@@ -2524,18 +2524,19 @@ getvalue(struct magic_set *ms, struct magic *m, const char **p, int action)
 			return -1;
 		}
 		if (m->type == FILE_REGEX) {
-			/*  XXX do we need this? */
-			/*zval pattern;
+			zval pattern;
 			int options = 0;
 			pcre_cache_entry *pce;
 
 			convert_libmagic_pattern(&pattern, m->value.s, strlen(m->value.s), options);
 
 			if ((pce = pcre_get_compiled_regex_cache(Z_STR(pattern))) == NULL) {
+				zval_dtor(&pattern);
 				return -1;	
 			}
+			zval_dtor(&pattern);
 
-			return 0;*/
+			return 0;
 		}
 		return 0;
 	case FILE_FLOAT:
@@ -2909,7 +2910,7 @@ apprentice_map(struct magic_set *ms, const char *fn)
 	if (dbname == NULL)
 		goto error;
 
-		stream = php_stream_open_wrapper((char *)fn, "rb", REPORT_ERRORS, NULL);
+	stream = php_stream_open_wrapper((char *)fn, "rb", REPORT_ERRORS, NULL);
 
 	if (!stream) {
 		goto error;
